@@ -26,7 +26,8 @@ lgreen = '\033[92m'
 clear = '\033[0m'
 bold = '\033[01m'
 cyan = '\033[96m'
-version = "1.2.3"
+version = "1.2.5"
+referer_list = ["https://www.google.com/", "https://www.youtube.com/", "https://www.twitter.com/", "https://www.discord.com/", "https://www.tiktok.com/", "https://www.instagram.com/"]
 
 major = str(sys.version_info.major)
 minor = str(sys.version_info.minor)
@@ -261,8 +262,6 @@ class ip:
     def telegram(data=False):
         import requests
         infinity = requests.get("https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json").json()
-        infi_ip = infinity["ip"]
-        infi_port = infinity["port"]
         socks_ip = infinity["socksip"]
         socks_port = infinity["socksport"]
         if data:
@@ -280,7 +279,6 @@ class ip:
            time.sleep(2)
            done = True
            print("Proxies http(s)")
-           print(infi_ip+":"+infi_port)
            print(get.text)
         else:
            get = requests.get("https://api.proxyscrape.com/v2/?request=displayproxies&protocol=socks5&timeout=250")
@@ -306,14 +304,14 @@ class ip:
            proxy.append(proxis)
            proxy_list = pyproxify.fetch(count=7, google=True, https=True)
            for item in proxy_list:
-              ip = item["ip"]
-              port = item["port"]
-              proxy.append(ip+":"+port)
+               ip = item["ip"]
+               port = item["port"]
+               proxy.append(ip+":"+port)
            proxy_list = pyproxify.fetch(count=8, https=True)
            for item in proxy_list:
-              ip = item["ip"]
-              port = item["port"]
-              proxy.append(ip+":"+port)
+               ip = item["ip"]
+               port = item["port"]
+               proxy.append(ip+":"+port)
            return proxy
         else:
            done = False
@@ -331,36 +329,21 @@ class ip:
            done = True
            proxy_list = pyproxify.fetch(count=3, google=True, https=True)
            for item in proxy_list:
-              ip = item["ip"]
-              port = item["port"]
-              last = item["last_update"]
-              anonymity = item["anonymity"]
-              country = item["country"]
-              c_name = country["name"]
-              print("Ip         : "+ip)
-              print("Port       : "+port)
-              print("Https      : False")
-              print("Google     : True")
-              print("Country    : "+c_name)
-              print("Checked    : "+last)
-              print("Anonymity  : "+anonymity)
-              print(" ")
-           proxy_list = pyproxify.fetch(count=2, google=False, https=True)
-           for item in proxy_list:9
-              ip = item["ip"]
-              port = item["port"]
-              last = item["last_update"]
-              anonymity = item["anonymity"]
-              country = item["country"]
-              c_name = country["name"]
-              print("Ip         : "+ip)
-              print("Port       : "+port)
-              print("Https      : False")
-              print("Google     : False")
-              print("Country    : "+c_name)
-              print("Checked    : "+last)
-              print("Anonymity  : "+anonymity)
-              print(" ")
+               ip = item["ip"]
+               port = item["port"]
+               last = item["last_update"]
+               anonymity = item["anonymity"]
+               country = item["country"]
+               c_name = country["name"]
+               print("Ip         : "+ip)
+               print("Port       : "+port)
+               print("Https      : False")
+               print("Google     : True")
+               print("Country    : "+c_name)
+               print("Checked    : "+last)
+               print("Anonymity  : "+anonymity)
+               print(" ")
+
 class check:
     def proxy(ip, port):
         import requests
@@ -446,7 +429,8 @@ class inquiry:
                          url = args.replace("https", "http")
                          if log:
                              print("[90%] Requests get URL")
-                         get = s.get(url, **kwargs, headers={"User-Agent": ua.windows()})
+                         referer = random.choice(referer_list)
+                         get = s.get(url, **kwargs, headers={"Referer": referer, "User-Agent": ua.windows()})
                          if log:
                              print("[100%] Success")
                          return get
@@ -464,11 +448,13 @@ class inquiry:
                      with eventlet.Timeout(15) as timeoo:
                          with requests.Session() as ss:
                              ss.proxies.update(proxies)
-                             get = ss.get(args, **kwargs, headers={"User-Agent": ua.windows()})
+                             referer = random.choice(referer_list)
+                             get = ss.get(args, **kwargs, headers={"Referer": referer, "User-Agent": ua.windows()})
                              if log:
                                  print("[100%] Success")
                              return get
                  except:
+
                      return '\033[91m403 Website refused to connect\x1B[37m'
         elif anon == "web":
             try:
@@ -484,7 +470,8 @@ class inquiry:
                 paste = "https://api.scraperapi.com?api_key="+key+"&url="+url
                 if log:
                     print("[90%] Requests get URL")
-                get = requests.get(paste, headers={"User-Agent": ua.linux()})
+                referer = random.choice(referer_list)
+                get = requests.get(paste, headers={"Referer": referer, "User-Agent": ua.linux()})
                 if log:
                     print("[100%] Success")
                 return get
